/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  main.c - c file for main function
 *  DRV8850 Electric Toothbrush Design FIRMWARE
 *  8/3/2015
 *
 ******************************************************************************/

#include "msp430.h"

// Port 1 output definitions
#define IN1H			BIT7	// P1.7
#define IN1L			BIT2	// P1.2
#define IN2H			BIT5	// P1.5
#define IN2L			BIT6	// P1.6

// Define output PWM waveform parameters
#define t_OFF			750		// Time that both outputs maintain low; 5*150
#define t_ON			1350	// Time that one output maintains high; 9*150

volatile unsigned int count;

int main(void)
{
	// Setup CLKs

	// Stop watchdog timer
	WDTCTL = WDTPW + WDTHOLD;

	// 1MHZ DCO
	BCSCTL1 = CALBC1_1MHZ;
	DCOCTL = CALDCO_1MHZ;

	// Configure all GPIO with pulldowns
  	P1REN  = BIT7 + BIT6 + BIT5 + BIT4 + BIT3 + BIT2 + BIT1 + BIT0;
  	P2REN  = BIT7 + BIT6;

  	// Set the four GPIO pins as OUTPUT
  	P1DIR = 0xE4;

  	// Set default GPIO settings
  	P1OUT  = 0x00;
  	P2OUT  = 0x00;

    // Setup Timer
    TACCTL0= CCIE;			// Enable Interrupts on Timer
    TACCR0 = 150-1;			// Number of cycles in the timer
    TACTL = TASSEL_2;		// Use SMCLK as source for timer
    TACTL |= MC_1;			// Use UP mode timer

	// Enters low power mode and enables interrupt
    __bis_SR_register(LPM0_bits + GIE);

} 	// main

#pragma vector = TIMERA0_VECTOR
/*		 |	  ____         |			|				 |
 * 	IN1H | __|	  |_______ |			|				 |
 * 		 |		      ____ |			|	____		 |
 * 	IN1L | __________|	  ||		OUT1|__|	|________|
 * 		 |			  ____ |			|			____ |
 * 	IN2H | __________|	  ||		OUT2|__________|	||
 * 		 |	  ____         |			|				 |
 * 	IN2L | __|	  |________|			|				 |
 */
__interrupt void CCR0_ISR(void)	{

	count++;						// Increment count upon every interrupt

    if 		(count == 5)			// 750 uS
    		P1OUT = IN1H + IN2L;	// OUT1 high

    else if (count == 14)			// 2100 uS
    		P1OUT = IN1L+IN2L;		// Slow decay

   	else if (count == 19)			// 2850
   			P1OUT = IN2H + IN1L;	// OUT2 high

    else if (count == 28)	{		// 4200
    		P1OUT = IN1L+IN2L;		// Slow decay
    		count = 0;
    }
    else	{
    	// Do nothing
    	}
}//interrupt
